# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from instana_client.models.custom_dashboard import CustomDashboard
from instana_client.models.custom_dashboard_preview import CustomDashboardPreview
from instana_client.models.custom_dashboard_with_user_specific_information import CustomDashboardWithUserSpecificInformation
from instana_client.models.dashboard_api_token import DashboardApiToken
from instana_client.models.user_basic_result import UserBasicResult

from instana_client.api_client import ApiClient, RequestSerialized
from instana_client.api_response import ApiResponse
from instana_client.rest import RESTResponseType


class CustomDashboardsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def add_custom_dashboard(
        self,
        custom_dashboard: Optional[CustomDashboard] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CustomDashboard:
        """Add custom dashboard

         For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param custom_dashboard:
        :type custom_dashboard: CustomDashboard
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_custom_dashboard_serialize(
            custom_dashboard=custom_dashboard,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomDashboard",
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def add_custom_dashboard_with_http_info(
        self,
        custom_dashboard: Optional[CustomDashboard] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CustomDashboard]:
        """Add custom dashboard

         For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param custom_dashboard:
        :type custom_dashboard: CustomDashboard
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_custom_dashboard_serialize(
            custom_dashboard=custom_dashboard,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomDashboard",
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def add_custom_dashboard_without_preload_content(
        self,
        custom_dashboard: Optional[CustomDashboard] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Add custom dashboard

         For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param custom_dashboard:
        :type custom_dashboard: CustomDashboard
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_custom_dashboard_serialize(
            custom_dashboard=custom_dashboard,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomDashboard",
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _add_custom_dashboard_serialize(
        self,
        custom_dashboard,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if custom_dashboard is not None:
            _body_params = custom_dashboard


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/custom-dashboard',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_custom_dashboard(
        self,
        custom_dashboard_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Remove custom dashboard

         For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param custom_dashboard_id: (required)
        :type custom_dashboard_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_custom_dashboard_serialize(
            custom_dashboard_id=custom_dashboard_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_custom_dashboard_with_http_info(
        self,
        custom_dashboard_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Remove custom dashboard

         For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param custom_dashboard_id: (required)
        :type custom_dashboard_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_custom_dashboard_serialize(
            custom_dashboard_id=custom_dashboard_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_custom_dashboard_without_preload_content(
        self,
        custom_dashboard_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Remove custom dashboard

         For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param custom_dashboard_id: (required)
        :type custom_dashboard_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_custom_dashboard_serialize(
            custom_dashboard_id=custom_dashboard_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_custom_dashboard_serialize(
        self,
        custom_dashboard_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if custom_dashboard_id is not None:
            _path_params['customDashboardId'] = custom_dashboard_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/custom-dashboard/{customDashboardId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_custom_dashboard(
        self,
        custom_dashboard_id: Annotated[StrictStr, Field(description="customDashboardId")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CustomDashboardWithUserSpecificInformation:
        """Get custom dashboard

        Get all Custom Dashboard Info for specified customDashboardId. For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param custom_dashboard_id: customDashboardId (required)
        :type custom_dashboard_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_custom_dashboard_serialize(
            custom_dashboard_id=custom_dashboard_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomDashboardWithUserSpecificInformation",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_custom_dashboard_with_http_info(
        self,
        custom_dashboard_id: Annotated[StrictStr, Field(description="customDashboardId")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CustomDashboardWithUserSpecificInformation]:
        """Get custom dashboard

        Get all Custom Dashboard Info for specified customDashboardId. For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param custom_dashboard_id: customDashboardId (required)
        :type custom_dashboard_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_custom_dashboard_serialize(
            custom_dashboard_id=custom_dashboard_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomDashboardWithUserSpecificInformation",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_custom_dashboard_without_preload_content(
        self,
        custom_dashboard_id: Annotated[StrictStr, Field(description="customDashboardId")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get custom dashboard

        Get all Custom Dashboard Info for specified customDashboardId. For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param custom_dashboard_id: customDashboardId (required)
        :type custom_dashboard_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_custom_dashboard_serialize(
            custom_dashboard_id=custom_dashboard_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomDashboardWithUserSpecificInformation",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_custom_dashboard_serialize(
        self,
        custom_dashboard_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if custom_dashboard_id is not None:
            _path_params['customDashboardId'] = custom_dashboard_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/custom-dashboard/{customDashboardId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_custom_dashboards(
        self,
        query: Annotated[Optional[StrictStr], Field(description="query")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="pageSize")] = None,
        page: Annotated[Optional[StrictInt], Field(description="page")] = None,
        with_total_hits: Annotated[Optional[StrictBool], Field(description="withTotalHits")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[CustomDashboardPreview]:
        """Get accessible custom dashboards

        Get all accessible custom dashboards details. For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param query: query
        :type query: str
        :param page_size: pageSize
        :type page_size: int
        :param page: page
        :type page: int
        :param with_total_hits: withTotalHits
        :type with_total_hits: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_custom_dashboards_serialize(
            query=query,
            page_size=page_size,
            page=page,
            with_total_hits=with_total_hits,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[CustomDashboardPreview]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_custom_dashboards_with_http_info(
        self,
        query: Annotated[Optional[StrictStr], Field(description="query")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="pageSize")] = None,
        page: Annotated[Optional[StrictInt], Field(description="page")] = None,
        with_total_hits: Annotated[Optional[StrictBool], Field(description="withTotalHits")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[CustomDashboardPreview]]:
        """Get accessible custom dashboards

        Get all accessible custom dashboards details. For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param query: query
        :type query: str
        :param page_size: pageSize
        :type page_size: int
        :param page: page
        :type page: int
        :param with_total_hits: withTotalHits
        :type with_total_hits: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_custom_dashboards_serialize(
            query=query,
            page_size=page_size,
            page=page,
            with_total_hits=with_total_hits,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[CustomDashboardPreview]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_custom_dashboards_without_preload_content(
        self,
        query: Annotated[Optional[StrictStr], Field(description="query")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="pageSize")] = None,
        page: Annotated[Optional[StrictInt], Field(description="page")] = None,
        with_total_hits: Annotated[Optional[StrictBool], Field(description="withTotalHits")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get accessible custom dashboards

        Get all accessible custom dashboards details. For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param query: query
        :type query: str
        :param page_size: pageSize
        :type page_size: int
        :param page: page
        :type page: int
        :param with_total_hits: withTotalHits
        :type with_total_hits: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_custom_dashboards_serialize(
            query=query,
            page_size=page_size,
            page=page,
            with_total_hits=with_total_hits,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[CustomDashboardPreview]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_custom_dashboards_serialize(
        self,
        query,
        page_size,
        page,
        with_total_hits,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if query is not None:
            
            _query_params.append(('query', query))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if with_total_hits is not None:
            
            _query_params.append(('withTotalHits', with_total_hits))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/custom-dashboard',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_shareable_api_tokens(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[DashboardApiToken]:
        """Get all API tokens.

        Get all API tokens that have access to shareable custom dashboards. For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_shareable_api_tokens_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[DashboardApiToken]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_shareable_api_tokens_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[DashboardApiToken]]:
        """Get all API tokens.

        Get all API tokens that have access to shareable custom dashboards. For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_shareable_api_tokens_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[DashboardApiToken]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_shareable_api_tokens_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all API tokens.

        Get all API tokens that have access to shareable custom dashboards. For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_shareable_api_tokens_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[DashboardApiToken]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_shareable_api_tokens_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/custom-dashboard/shareable-api-tokens',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_shareable_users(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[UserBasicResult]:
        """Get all users (without invitations).

        Get all users (without invitations) that have access to shareable custom dashboards. For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_shareable_users_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[UserBasicResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_shareable_users_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[UserBasicResult]]:
        """Get all users (without invitations).

        Get all users (without invitations) that have access to shareable custom dashboards. For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_shareable_users_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[UserBasicResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_shareable_users_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all users (without invitations).

        Get all users (without invitations) that have access to shareable custom dashboards. For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_shareable_users_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[UserBasicResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_shareable_users_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/custom-dashboard/shareable-users',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_custom_dashboard(
        self,
        custom_dashboard_id: StrictStr,
        custom_dashboard: Optional[CustomDashboard] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CustomDashboard:
        """Update custom dashboard

         For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param custom_dashboard_id: (required)
        :type custom_dashboard_id: str
        :param custom_dashboard:
        :type custom_dashboard: CustomDashboard
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_custom_dashboard_serialize(
            custom_dashboard_id=custom_dashboard_id,
            custom_dashboard=custom_dashboard,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomDashboard",
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_custom_dashboard_with_http_info(
        self,
        custom_dashboard_id: StrictStr,
        custom_dashboard: Optional[CustomDashboard] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CustomDashboard]:
        """Update custom dashboard

         For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param custom_dashboard_id: (required)
        :type custom_dashboard_id: str
        :param custom_dashboard:
        :type custom_dashboard: CustomDashboard
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_custom_dashboard_serialize(
            custom_dashboard_id=custom_dashboard_id,
            custom_dashboard=custom_dashboard,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomDashboard",
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_custom_dashboard_without_preload_content(
        self,
        custom_dashboard_id: StrictStr,
        custom_dashboard: Optional[CustomDashboard] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update custom dashboard

         For more information on custom dashboards please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Settings#custom-dashboards.

        :param custom_dashboard_id: (required)
        :type custom_dashboard_id: str
        :param custom_dashboard:
        :type custom_dashboard: CustomDashboard
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_custom_dashboard_serialize(
            custom_dashboard_id=custom_dashboard_id,
            custom_dashboard=custom_dashboard,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomDashboard",
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_custom_dashboard_serialize(
        self,
        custom_dashboard_id,
        custom_dashboard,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if custom_dashboard_id is not None:
            _path_params['customDashboardId'] = custom_dashboard_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if custom_dashboard is not None:
            _body_params = custom_dashboard


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/custom-dashboard/{customDashboardId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.trace import Trace

class TestTrace(unittest.TestCase):
    """Trace unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Trace:
        """Test Trace
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Trace`
        """
        model = Trace()
        if include_optional:
            return Trace(
                duration = 0,
                endpoint = instana_client.models.endpoint.Endpoint(
                    entity_type = 'APPLICATION', 
                    id = '', 
                    is_synthetic = True, 
                    label = '', 
                    service_id = '', 
                    synthetic = True, 
                    synthetic_type = 'NON_SYNTHETIC', 
                    technologies = [
                        ''
                        ], 
                    type = 'UNDEFINED', ),
                erroneous = True,
                id = '',
                label = '',
                service = instana_client.models.service.Service(
                    entity_type = 'APPLICATION', 
                    id = '', 
                    label = '', 
                    snapshot_ids = [
                        ''
                        ], 
                    technologies = [
                        ''
                        ], 
                    types = [
                        'UNDEFINED'
                        ], ),
                start_time = 1
            )
        else:
            return Trace(
                id = '',
                label = '',
        )
        """

    def testTrace(self):
        """Test Trace"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.event_filtering_configuration import EventFilteringConfiguration

class TestEventFilteringConfiguration(unittest.TestCase):
    """EventFilteringConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EventFilteringConfiguration:
        """Test EventFilteringConfiguration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EventFilteringConfiguration`
        """
        model = EventFilteringConfiguration()
        if include_optional:
            return EventFilteringConfiguration(
                application_alert_config_ids = [
                    ''
                    ],
                event_types = [
                    'incident'
                    ],
                query = '',
                rule_ids = [
                    ''
                    ]
            )
        else:
            return EventFilteringConfiguration(
        )
        """

    def testEventFilteringConfiguration(self):
        """Test EventFilteringConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.custom_dashboards_api import CustomDashboardsApi


class TestCustomDashboardsApi(unittest.TestCase):
    """CustomDashboardsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CustomDashboardsApi()

    def tearDown(self) -> None:
        pass

    def test_add_custom_dashboard(self) -> None:
        """Test case for add_custom_dashboard

        Add custom dashboard
        """
        pass

    def test_delete_custom_dashboard(self) -> None:
        """Test case for delete_custom_dashboard

        Remove custom dashboard
        """
        pass

    def test_get_custom_dashboard(self) -> None:
        """Test case for get_custom_dashboard

        Get custom dashboard
        """
        pass

    def test_get_custom_dashboards(self) -> None:
        """Test case for get_custom_dashboards

        Get accessible custom dashboards
        """
        pass

    def test_get_shareable_api_tokens(self) -> None:
        """Test case for get_shareable_api_tokens

        Get all API tokens.
        """
        pass

    def test_get_shareable_users(self) -> None:
        """Test case for get_shareable_users

        Get all users (without invitations).
        """
        pass

    def test_update_custom_dashboard(self) -> None:
        """Test case for update_custom_dashboard

        Update custom dashboard
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.application_settings_api import ApplicationSettingsApi


class TestApplicationSettingsApi(unittest.TestCase):
    """ApplicationSettingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationSettingsApi()

    def tearDown(self) -> None:
        pass

    def test_add_application_config(self) -> None:
        """Test case for add_application_config

        Add application configuration
        """
        pass

    def test_add_manual_service_config(self) -> None:
        """Test case for add_manual_service_config

        Add manual service configuration
        """
        pass

    def test_add_service_config(self) -> None:
        """Test case for add_service_config

        Add service configuration
        """
        pass

    def test_create_endpoint_config(self) -> None:
        """Test case for create_endpoint_config

        Create endpoint configuration
        """
        pass

    def test_create_http_endpoint_config(self) -> None:
        """Test case for create_http_endpoint_config

        Create HTTP endpoint configuration
        """
        pass

    def test_delete_application_config(self) -> None:
        """Test case for delete_application_config

        Delete application configuration
        """
        pass

    def test_delete_endpoint_config(self) -> None:
        """Test case for delete_endpoint_config

        Delete endpoint configuration
        """
        pass

    def test_delete_http_endpoint_config(self) -> None:
        """Test case for delete_http_endpoint_config

        Delete HTTP endpoint configuration
        """
        pass

    def test_delete_manual_service_config(self) -> None:
        """Test case for delete_manual_service_config

        Delete manual service configuration
        """
        pass

    def test_delete_service_config(self) -> None:
        """Test case for delete_service_config

        Delete service configuration
        """
        pass

    def test_get_all_manual_service_configs(self) -> None:
        """Test case for get_all_manual_service_configs

        All manual service configurations
        """
        pass

    def test_get_application_config(self) -> None:
        """Test case for get_application_config

        Application configuration
        """
        pass

    def test_get_application_configs(self) -> None:
        """Test case for get_application_configs

        All Application configurations
        """
        pass

    def test_get_endpoint_config(self) -> None:
        """Test case for get_endpoint_config

        Endpoint configuration
        """
        pass

    def test_get_endpoint_configs(self) -> None:
        """Test case for get_endpoint_configs

        All Endpoint configurations
        """
        pass

    def test_get_http_endpoint_config(self) -> None:
        """Test case for get_http_endpoint_config

        HTTP Endpoint configuration
        """
        pass

    def test_get_http_endpoint_configs(self) -> None:
        """Test case for get_http_endpoint_configs

        All HTTP endpoint configurations
        """
        pass

    def test_get_service_config(self) -> None:
        """Test case for get_service_config

        Service configuration
        """
        pass

    def test_get_service_configs(self) -> None:
        """Test case for get_service_configs

        All service configurations
        """
        pass

    def test_order_service_config(self) -> None:
        """Test case for order_service_config

        Order of service configuration
        """
        pass

    def test_put_application_config(self) -> None:
        """Test case for put_application_config

        Update application configuration
        """
        pass

    def test_put_service_config(self) -> None:
        """Test case for put_service_config

        Update service configuration
        """
        pass

    def test_replace_all(self) -> None:
        """Test case for replace_all

        Replace all service configurations
        """
        pass

    def test_replace_all_manual_service_configs(self) -> None:
        """Test case for replace_all_manual_service_configs

        Replace all manual service configurations
        """
        pass

    def test_update_endpoint_config(self) -> None:
        """Test case for update_endpoint_config

        Update endpoint configuration
        """
        pass

    def test_update_http_endpoint_config(self) -> None:
        """Test case for update_http_endpoint_config

        Update HTTP endpoint configuration
        """
        pass

    def test_update_manual_service_config(self) -> None:
        """Test case for update_manual_service_config

        Update manual service configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.custom_event_specification import CustomEventSpecification

class TestCustomEventSpecification(unittest.TestCase):
    """CustomEventSpecification unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomEventSpecification:
        """Test CustomEventSpecification
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomEventSpecification`
        """
        model = CustomEventSpecification()
        if include_optional:
            return CustomEventSpecification(
                actions = [
                    instana_client.models.action.Action(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        fields = [
                            instana_client.models.field.Field(
                                description = '', 
                                encoding = '', 
                                name = '', 
                                secured = True, 
                                value = '', )
                            ], 
                        id = '0', 
                        input_parameters = [
                            instana_client.models.parameter.Parameter(
                                description = '', 
                                hidden = True, 
                                label = '', 
                                name = '', 
                                required = True, 
                                secured = True, 
                                type = '', 
                                value = '', )
                            ], 
                        metadata = instana_client.models.meta_data.MetaData(
                            ai = [
                                {
                                    'key' : None
                                    }
                                ], 
                            ai_originated = True, 
                            built_in = True, 
                            read_only = True, 
                            sensor_imported = True, ), 
                        modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '0', 
                        tags = [
                            ''
                            ], 
                        type = 'SCRIPT', )
                    ],
                description = '',
                enabled = True,
                entity_type = '',
                expiration_time = 56,
                name = '',
                query = '',
                rule_logical_operator = 'AND',
                rules = [
                    instana_client.models.abstract_rule.AbstractRule(
                        rule_type = '', 
                        severity = 56, )
                    ],
                transient_event_alert_muted = True,
                transient_event_enabled = True,
                transient_event_threshold = 56,
                triggering = True
            )
        else:
            return CustomEventSpecification(
                entity_type = '',
                name = '',
                rules = [
                    instana_client.models.abstract_rule.AbstractRule(
                        rule_type = '', 
                        severity = 56, )
                    ],
        )
        """

    def testCustomEventSpecification(self):
        """Test CustomEventSpecification"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.application_metric_result import ApplicationMetricResult

class TestApplicationMetricResult(unittest.TestCase):
    """ApplicationMetricResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApplicationMetricResult:
        """Test ApplicationMetricResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApplicationMetricResult`
        """
        model = ApplicationMetricResult()
        if include_optional:
            return ApplicationMetricResult(
                adjusted_timeframe = instana_client.models.adjusted_timeframe.AdjustedTimeframe(
                    to = 56, 
                    window_size = 0, ),
                items = [
                    instana_client.models.application_item.ApplicationItem(
                        application = instana_client.models.application.Application(
                            boundary_scope = '', 
                            entity_type = 'APPLICATION', 
                            id = '', 
                            label = '', ), 
                        metrics = {
                            'key' : [
                                [
                                    1.337
                                    ]
                                ]
                            }, )
                    ],
                page = 1,
                page_size = 1,
                total_hits = 0
            )
        else:
            return ApplicationMetricResult(
                items = [
                    instana_client.models.application_item.ApplicationItem(
                        application = instana_client.models.application.Application(
                            boundary_scope = '', 
                            entity_type = 'APPLICATION', 
                            id = '', 
                            label = '', ), 
                        metrics = {
                            'key' : [
                                [
                                    1.337
                                    ]
                                ]
                            }, )
                    ],
        )
        """

    def testApplicationMetricResult(self):
        """Test ApplicationMetricResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.api_tag import ApiTag
from typing import Optional, Set
from typing_extensions import Self

class SyntheticCredential(BaseModel):
    """
    SyntheticCredential
    """ # noqa: E501
    application_labels: Optional[List[StrictStr]] = Field(default=None, alias="applicationLabels")
    applications: Optional[List[StrictStr]] = None
    created_at: Optional[StrictInt] = Field(default=None, alias="createdAt")
    created_by: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=128)]] = Field(default=None, alias="createdBy")
    credential_name: Annotated[str, Field(min_length=1, strict=True, max_length=128)] = Field(alias="credentialName")
    credential_value: StrictStr = Field(alias="credentialValue")
    mobile_app_labels: Optional[List[StrictStr]] = Field(default=None, alias="mobileAppLabels")
    mobile_apps: Optional[List[StrictStr]] = Field(default=None, alias="mobileApps")
    modified_at: Optional[StrictInt] = Field(default=None, alias="modifiedAt")
    modified_by: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=128)]] = Field(default=None, alias="modifiedBy")
    rbac_tags: Optional[List[ApiTag]] = Field(default=None, alias="rbacTags")
    website_labels: Optional[List[StrictStr]] = Field(default=None, alias="websiteLabels")
    websites: Optional[List[StrictStr]] = None
    __properties: ClassVar[List[str]] = ["applicationLabels", "applications", "createdAt", "createdBy", "credentialName", "credentialValue", "mobileAppLabels", "mobileApps", "modifiedAt", "modifiedBy", "rbacTags", "websiteLabels", "websites"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SyntheticCredential from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "application_labels",
            "created_at",
            "mobile_app_labels",
            "modified_at",
            "website_labels",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in rbac_tags (list)
        _items = []
        if self.rbac_tags:
            for _item_rbac_tags in self.rbac_tags:
                if _item_rbac_tags:
                    _items.append(_item_rbac_tags.to_dict())
            _dict['rbacTags'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SyntheticCredential from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "applicationLabels": obj.get("applicationLabels"),
            "applications": obj.get("applications"),
            "createdAt": obj.get("createdAt"),
            "createdBy": obj.get("createdBy"),
            "credentialName": obj.get("credentialName"),
            "credentialValue": obj.get("credentialValue"),
            "mobileAppLabels": obj.get("mobileAppLabels"),
            "mobileApps": obj.get("mobileApps"),
            "modifiedAt": obj.get("modifiedAt"),
            "modifiedBy": obj.get("modifiedBy"),
            "rbacTags": [ApiTag.from_dict(_item) for _item in obj["rbacTags"]] if obj.get("rbacTags") is not None else None,
            "websiteLabels": obj.get("websiteLabels"),
            "websites": obj.get("websites")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.http_endpoint_rule import HttpEndpointRule
from typing import Optional, Set
from typing_extensions import Self

class EndpointConfig(BaseModel):
    """
    EndpointConfig
    """ # noqa: E501
    endpoint_case: StrictStr = Field(description="This represents case sensitivity of endpoints of a service. Let's say in a service there are three endpoints, `user`, `Order` and `PAYMENT`:   For example, if `endpointCase` is `UPPER`, then endpoint names are converted to `USER`, `ORDER` and `PAYMENT`.   If `endpointCase` is `LOWER`, then endpoint names are converted to `user`, `order` and `payment`.   If `endpointCase` is `ORIGINAL`, then endpoint names are converted to `user`, `Order` and `PAYMENT`. ", alias="endpointCase")
    endpoint_name_by_collected_path_template_rule_enabled: Optional[StrictBool] = Field(default=None, description="The highest default precedence of endpoint rule is creating endpoint is based on path template. For example, ``` /hospital/1948/patient/291148 /hospital/728/patient/924892 /hospital/47/patient/25978 /hospital/108429/patient/1847 ``` can be considered as `/hospital/{hid}/patient/{pid}` if this rule is enabled. For most of the use cases, this rule should be enabled. ", alias="endpointNameByCollectedPathTemplateRuleEnabled")
    endpoint_name_by_first_path_segment_rule_enabled: Optional[StrictBool] = Field(default=None, description="There are endpoint extraction rules in Instana which take the first path segment from the HTTP request and turn this into an endpoint name. For example, given the following URLs `/users/123/profile` and `/users/123/settings`, the extraction rule will only take the first segment. As a result endpoint name will be `users`. Although this is useful in cases where broad overview of monitoring is required, lot of use cases are more specified. Considering the above example, if this rule is enabled, Instana can't distinguish between `profile` or `settings` as endpoints. For use cases where endpoints has to be monitored at fine granular level, this flag should be set to `false`. ", alias="endpointNameByFirstPathSegmentRuleEnabled")
    rules: Optional[Annotated[List[HttpEndpointRule], Field(min_length=1, max_length=500)]] = Field(default=None, description="Specify custom rule configuration apart from Instana predefined rules. This rule has the highest precedence. This is only available for HTTP endpoints.")
    service_id: StrictStr = Field(description="An Instana generated unique identifier for a Service. If specified, the list of results will be filtered for the specified Service ID. Eg: `3feb3dcd206c166ef2b41c707e0cd38d7cd325aa`. One can see the service id from Instana UI by going to a Service page. In the URL, there will be `serviceId=3feb3dcd206c166ef2b41c707e0cd38d7cd325aa`. Alternatively, one can use `Get services` API endpoint to get the service id in `id` parameter. ", alias="serviceId")
    __properties: ClassVar[List[str]] = ["endpointCase", "endpointNameByCollectedPathTemplateRuleEnabled", "endpointNameByFirstPathSegmentRuleEnabled", "rules", "serviceId"]

    @field_validator('endpoint_case')
    def endpoint_case_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['ORIGINAL', 'LOWER', 'UPPER']):
            raise ValueError("must be one of enum values ('ORIGINAL', 'LOWER', 'UPPER')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EndpointConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in rules (list)
        _items = []
        if self.rules:
            for _item_rules in self.rules:
                if _item_rules:
                    _items.append(_item_rules.to_dict())
            _dict['rules'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EndpointConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "endpointCase": obj.get("endpointCase"),
            "endpointNameByCollectedPathTemplateRuleEnabled": obj.get("endpointNameByCollectedPathTemplateRuleEnabled"),
            "endpointNameByFirstPathSegmentRuleEnabled": obj.get("endpointNameByFirstPathSegmentRuleEnabled"),
            "rules": [HttpEndpointRule.from_dict(_item) for _item in obj["rules"]] if obj.get("rules") is not None else None,
            "serviceId": obj.get("serviceId")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.custom_payload_field import CustomPayloadField
from instana_client.models.service_levels_alert_rule import ServiceLevelsAlertRule
from instana_client.models.service_levels_burn_rate_config import ServiceLevelsBurnRateConfig
from instana_client.models.service_levels_burn_rate_time_windows import ServiceLevelsBurnRateTimeWindows
from instana_client.models.service_levels_time_threshold import ServiceLevelsTimeThreshold
from instana_client.models.static_threshold import StaticThreshold
from typing import Optional, Set
from typing_extensions import Self

class ServiceLevelsAlertConfig(BaseModel):
    """
    ServiceLevelsAlertConfig
    """ # noqa: E501
    alert_channel_ids: Annotated[List[StrictStr], Field(min_length=0, max_length=1024)] = Field(description="This is the list of channel IDs when alert triggered and sent to.", alias="alertChannelIds")
    burn_rate_config: Optional[List[ServiceLevelsBurnRateConfig]] = Field(default=None, description="This is the burn rate alert configuration which defines alerting windows and corresponding thresholds. This configuration must to specified for BURN_RATE_V2 Alerts.", alias="burnRateConfig")
    burn_rate_time_windows: Optional[ServiceLevelsBurnRateTimeWindows] = Field(default=None, alias="burnRateTimeWindows")
    custom_payload_fields: Annotated[List[CustomPayloadField], Field(min_length=0, max_length=20)] = Field(description="This is the custom name and value pairs to be sent along with the alert to the alert channels.", alias="customPayloadFields")
    description: Annotated[str, Field(min_length=0, strict=True, max_length=65536)] = Field(description="The description of the alert. It is also the alert message content.")
    name: Annotated[str, Field(min_length=0, strict=True, max_length=256)] = Field(description="Name of the Service Levels Smart Alerts Configuration.")
    rule: ServiceLevelsAlertRule
    severity: StrictInt = Field(description="This is the severity of the alert. The value can be: <b>5</b>: warning, <b>10</b>: critical.")
    slo_ids: Annotated[List[StrictStr], Field(min_length=0, max_length=1024)] = Field(description="This is the list of SLO configurations related to this alert.", alias="sloIds")
    threshold: Optional[StaticThreshold] = None
    time_threshold: ServiceLevelsTimeThreshold = Field(alias="timeThreshold")
    triggering: Optional[StrictBool] = Field(default=None, description="Incident flag. If value is true, this alert will become an accident.")
    __properties: ClassVar[List[str]] = ["alertChannelIds", "burnRateConfig", "burnRateTimeWindows", "customPayloadFields", "description", "name", "rule", "severity", "sloIds", "threshold", "timeThreshold", "triggering"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServiceLevelsAlertConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in burn_rate_config (list)
        _items = []
        if self.burn_rate_config:
            for _item_burn_rate_config in self.burn_rate_config:
                if _item_burn_rate_config:
                    _items.append(_item_burn_rate_config.to_dict())
            _dict['burnRateConfig'] = _items
        # override the default output from pydantic by calling `to_dict()` of burn_rate_time_windows
        if self.burn_rate_time_windows:
            _dict['burnRateTimeWindows'] = self.burn_rate_time_windows.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in custom_payload_fields (list)
        _items = []
        if self.custom_payload_fields:
            for _item_custom_payload_fields in self.custom_payload_fields:
                if _item_custom_payload_fields:
                    _items.append(_item_custom_payload_fields.to_dict())
            _dict['customPayloadFields'] = _items
        # override the default output from pydantic by calling `to_dict()` of rule
        if self.rule:
            _dict['rule'] = self.rule.to_dict()
        # override the default output from pydantic by calling `to_dict()` of threshold
        if self.threshold:
            _dict['threshold'] = self.threshold.to_dict()
        # override the default output from pydantic by calling `to_dict()` of time_threshold
        if self.time_threshold:
            _dict['timeThreshold'] = self.time_threshold.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServiceLevelsAlertConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "alertChannelIds": obj.get("alertChannelIds"),
            "burnRateConfig": [ServiceLevelsBurnRateConfig.from_dict(_item) for _item in obj["burnRateConfig"]] if obj.get("burnRateConfig") is not None else None,
            "burnRateTimeWindows": ServiceLevelsBurnRateTimeWindows.from_dict(obj["burnRateTimeWindows"]) if obj.get("burnRateTimeWindows") is not None else None,
            "customPayloadFields": [CustomPayloadField.from_dict(_item) for _item in obj["customPayloadFields"]] if obj.get("customPayloadFields") is not None else None,
            "description": obj.get("description"),
            "name": obj.get("name"),
            "rule": ServiceLevelsAlertRule.from_dict(obj["rule"]) if obj.get("rule") is not None else None,
            "severity": obj.get("severity"),
            "sloIds": obj.get("sloIds"),
            "threshold": StaticThreshold.from_dict(obj["threshold"]) if obj.get("threshold") is not None else None,
            "timeThreshold": ServiceLevelsTimeThreshold.from_dict(obj["timeThreshold"]) if obj.get("timeThreshold") is not None else None,
            "triggering": obj.get("triggering")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.synthetic_alert_configuration_api import SyntheticAlertConfigurationApi


class TestSyntheticAlertConfigurationApi(unittest.TestCase):
    """SyntheticAlertConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SyntheticAlertConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_create_synthetic_alert_config(self) -> None:
        """Test case for create_synthetic_alert_config

        Create Synthetic Smart Alert Config
        """
        pass

    def test_delete_synthetic_alert_config(self) -> None:
        """Test case for delete_synthetic_alert_config

        Delete Synthetic Smart Alert Config
        """
        pass

    def test_disable_synthetic_alert_config(self) -> None:
        """Test case for disable_synthetic_alert_config

        Disable Synthetic Smart Alert Config
        """
        pass

    def test_enable_synthetic_alert_config(self) -> None:
        """Test case for enable_synthetic_alert_config

        Enable Synthetic Smart Alert Config
        """
        pass

    def test_find_active_synthetic_alert_configs(self) -> None:
        """Test case for find_active_synthetic_alert_configs

        Get all Synthetic Smart Alert Configs
        """
        pass

    def test_find_synthetic_alert_config(self) -> None:
        """Test case for find_synthetic_alert_config

        Get Synthetic Smart Alert Config
        """
        pass

    def test_find_synthetic_alert_config_versions(self) -> None:
        """Test case for find_synthetic_alert_config_versions

        Get Synthetic Smart Alert Config Versions
        """
        pass

    def test_restore_synthetic_alert_config(self) -> None:
        """Test case for restore_synthetic_alert_config

        Restore Synthetic Smart Alert Config
        """
        pass

    def test_update_synthetic_alert_config(self) -> None:
        """Test case for update_synthetic_alert_config

        Update Synthetic Smart Alert Config
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Endpoint(BaseModel):
    """
    Endpoint
    """ # noqa: E501
    entity_type: Optional[StrictStr] = Field(default=None, description="Since, this is a Endpoint, it will be of type `ENDPOINT`.", alias="entityType")
    id: StrictStr = Field(description="Unique ID of the Endpoint. Eg: `NCRq5oYnan5x-PkdTPQwLLUdu5M`.")
    is_synthetic: Optional[StrictBool] = Field(default=None, alias="isSynthetic")
    label: StrictStr = Field(description="Name of the Endpoint. Eg: `GET /api/fetch`.")
    service_id: StrictStr = Field(description="The serviceId this endpoint belongs to.", alias="serviceId")
    synthetic: Optional[StrictBool] = None
    synthetic_type: Optional[StrictStr] = Field(default=None, alias="syntheticType")
    technologies: List[StrictStr] = Field(description="List of technologies: `Eg:[\"springbootApplicationContainer\"]`")
    type: StrictStr = Field(description="The type of the Endpoint.")
    __properties: ClassVar[List[str]] = ["entityType", "id", "isSynthetic", "label", "serviceId", "synthetic", "syntheticType", "technologies", "type"]

    @field_validator('entity_type')
    def entity_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['APPLICATION', 'SERVICE', 'ENDPOINT']):
            raise ValueError("must be one of enum values ('APPLICATION', 'SERVICE', 'ENDPOINT')")
        return value

    @field_validator('synthetic_type')
    def synthetic_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['NON_SYNTHETIC', 'SYNTHETIC', 'MIXED']):
            raise ValueError("must be one of enum values ('NON_SYNTHETIC', 'SYNTHETIC', 'MIXED')")
        return value

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['UNDEFINED', 'RPC', 'EVENT', 'GRAPHQL', 'BATCH', 'SHELL', 'HTTP', 'SDK', 'OPENTELEMETRY', 'INTERNAL', 'DATABASE', 'MESSAGING', 'PAGE', 'PAGE_RESOURCE']):
            raise ValueError("must be one of enum values ('UNDEFINED', 'RPC', 'EVENT', 'GRAPHQL', 'BATCH', 'SHELL', 'HTTP', 'SDK', 'OPENTELEMETRY', 'INTERNAL', 'DATABASE', 'MESSAGING', 'PAGE', 'PAGE_RESOURCE')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Endpoint from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Endpoint from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "entityType": obj.get("entityType"),
            "id": obj.get("id"),
            "isSynthetic": obj.get("isSynthetic"),
            "label": obj.get("label"),
            "serviceId": obj.get("serviceId"),
            "synthetic": obj.get("synthetic"),
            "syntheticType": obj.get("syntheticType"),
            "technologies": obj.get("technologies"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.problem import Problem
from typing import Optional, Set
from typing_extensions import Self

class Event(BaseModel):
    """
    Event
    """ # noqa: E501
    affected_entities: Optional[List[StrictStr]] = Field(default=None, alias="affectedEntities")
    end: Optional[Annotated[int, Field(strict=True, ge=1)]] = None
    endpoint_service_id: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=64)]] = Field(default=None, alias="endpointServiceId")
    entity_id: Annotated[str, Field(min_length=0, strict=True, max_length=64)] = Field(alias="entityId")
    entity_type: Optional[StrictStr] = Field(default=None, alias="entityType")
    event_configuration_type: Optional[StrictStr] = Field(default=None, alias="eventConfigurationType")
    id: Annotated[str, Field(min_length=0, strict=True, max_length=64)]
    long_form_plugin_id: Optional[StrictStr] = Field(default=None, alias="longFormPluginId")
    metadata: Optional[Dict[str, Dict[str, Any]]] = None
    metric_access_id: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=64)]] = Field(default=None, alias="metricAccessId")
    plugin: Annotated[str, Field(min_length=0, strict=True, max_length=256)]
    problem: Optional[Problem] = None
    rca: Optional[Dict[str, Dict[str, Any]]] = None
    short_code: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=64)]] = Field(default=None, alias="shortCode")
    start: Optional[Annotated[int, Field(strict=True, ge=1)]] = None
    state: Annotated[str, Field(min_length=0, strict=True, max_length=8)]
    type: Annotated[str, Field(min_length=0, strict=True, max_length=64)]
    __properties: ClassVar[List[str]] = ["affectedEntities", "end", "endpointServiceId", "entityId", "entityType", "eventConfigurationType", "id", "longFormPluginId", "metadata", "metricAccessId", "plugin", "problem", "rca", "shortCode", "start", "state", "type"]

    @field_validator('entity_type')
    def entity_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Entity10', 'App20', 'Service20', 'Endpoint20', 'Website', 'Synthetic', 'MobileApp', 'Log']):
            raise ValueError("must be one of enum values ('Entity10', 'App20', 'Service20', 'Endpoint20', 'Website', 'Synthetic', 'MobileApp', 'Log')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Event from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of problem
        if self.problem:
            _dict['problem'] = self.problem.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Event from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "affectedEntities": obj.get("affectedEntities"),
            "end": obj.get("end"),
            "endpointServiceId": obj.get("endpointServiceId"),
            "entityId": obj.get("entityId"),
            "entityType": obj.get("entityType"),
            "eventConfigurationType": obj.get("eventConfigurationType"),
            "id": obj.get("id"),
            "longFormPluginId": obj.get("longFormPluginId"),
            "metadata": obj.get("metadata"),
            "metricAccessId": obj.get("metricAccessId"),
            "plugin": obj.get("plugin"),
            "problem": Problem.from_dict(obj["problem"]) if obj.get("problem") is not None else None,
            "rca": obj.get("rca"),
            "shortCode": obj.get("shortCode"),
            "start": obj.get("start"),
            "state": obj.get("state"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class BusinessActivity(BaseModel):
    """
    BusinessActivity
    """ # noqa: E501
    activity_id: Optional[StrictStr] = Field(default=None, description="Unique identifier for the activity generated by the source BPM tool", alias="activityId")
    activity_name: Optional[StrictStr] = Field(default=None, description="Name of the activity ", alias="activityName")
    activity_start: Optional[StrictInt] = Field(default=None, description="Unix timestamp representing the activity's start time", alias="activityStart")
    activity_type: StrictStr = Field(description="Type of the activity ", alias="activityType")
    call_id: Optional[StrictStr] = Field(default=None, alias="callId")
    endpoint_ids: Optional[List[StrictStr]] = Field(default=None, alias="endpointIds")
    process_definition_id: Optional[StrictStr] = Field(default=None, description="The identifier of the process the activity is an instance of.", alias="processDefinitionId")
    process_definition_name: Optional[StrictStr] = Field(default=None, description="The name of the process that the activity is an instance of", alias="processDefinitionName")
    root_process_instance_id: Optional[StrictStr] = Field(default=None, description="The id of the root process for the activity", alias="rootProcessInstanceId")
    __properties: ClassVar[List[str]] = ["activityId", "activityName", "activityStart", "activityType", "callId", "endpointIds", "processDefinitionId", "processDefinitionName", "rootProcessInstanceId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BusinessActivity from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if activity_id (nullable) is None
        # and model_fields_set contains the field
        if self.activity_id is None and "activity_id" in self.model_fields_set:
            _dict['activityId'] = None

        # set to None if activity_name (nullable) is None
        # and model_fields_set contains the field
        if self.activity_name is None and "activity_name" in self.model_fields_set:
            _dict['activityName'] = None

        # set to None if activity_start (nullable) is None
        # and model_fields_set contains the field
        if self.activity_start is None and "activity_start" in self.model_fields_set:
            _dict['activityStart'] = None

        # set to None if process_definition_id (nullable) is None
        # and model_fields_set contains the field
        if self.process_definition_id is None and "process_definition_id" in self.model_fields_set:
            _dict['processDefinitionId'] = None

        # set to None if process_definition_name (nullable) is None
        # and model_fields_set contains the field
        if self.process_definition_name is None and "process_definition_name" in self.model_fields_set:
            _dict['processDefinitionName'] = None

        # set to None if root_process_instance_id (nullable) is None
        # and model_fields_set contains the field
        if self.root_process_instance_id is None and "root_process_instance_id" in self.model_fields_set:
            _dict['rootProcessInstanceId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BusinessActivity from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "activityId": obj.get("activityId"),
            "activityName": obj.get("activityName"),
            "activityStart": obj.get("activityStart"),
            "activityType": obj.get("activityType"),
            "callId": obj.get("callId"),
            "endpointIds": obj.get("endpointIds"),
            "processDefinitionId": obj.get("processDefinitionId"),
            "processDefinitionName": obj.get("processDefinitionName"),
            "rootProcessInstanceId": obj.get("rootProcessInstanceId")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.event_settings_api import EventSettingsApi


class TestEventSettingsApi(unittest.TestCase):
    """EventSettingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EventSettingsApi()

    def tearDown(self) -> None:
        pass

    def test_create_mobile_app_alert_config(self) -> None:
        """Test case for create_mobile_app_alert_config

        Create Mobile Smart Alert Config
        """
        pass

    def test_create_website_alert_config(self) -> None:
        """Test case for create_website_alert_config

        Create Website Smart Alert Config
        """
        pass

    def test_delete_alert(self) -> None:
        """Test case for delete_alert

        Delete Alert Configuration
        """
        pass

    def test_delete_alerting_channel(self) -> None:
        """Test case for delete_alerting_channel

        Delete Alerting Channel
        """
        pass

    def test_delete_built_in_event_specification(self) -> None:
        """Test case for delete_built_in_event_specification

        Delete built-in event specification
        """
        pass

    def test_delete_custom_event_specification(self) -> None:
        """Test case for delete_custom_event_specification

        Delete custom event specification
        """
        pass

    def test_delete_custom_payload_configuration(self) -> None:
        """Test case for delete_custom_payload_configuration

        Delete Custom Payload Configuration
        """
        pass

    def test_delete_mobile_app_alert_config(self) -> None:
        """Test case for delete_mobile_app_alert_config

        Delete Mobile Smart Alert Config
        """
        pass

    def test_delete_website_alert_config(self) -> None:
        """Test case for delete_website_alert_config

        Delete Website Smart Alert Config
        """
        pass

    def test_disable_built_in_event_specification(self) -> None:
        """Test case for disable_built_in_event_specification

        Disable built-in event specification
        """
        pass

    def test_disable_custom_event_specification(self) -> None:
        """Test case for disable_custom_event_specification

        Disable custom event specification
        """
        pass

    def test_disable_mobile_app_alert_config(self) -> None:
        """Test case for disable_mobile_app_alert_config

        Disable Mobile Smart Alert Config
        """
        pass

    def test_disable_website_alert_config(self) -> None:
        """Test case for disable_website_alert_config

        Disable Website Smart Alert Config
        """
        pass

    def test_enable_built_in_event_specification(self) -> None:
        """Test case for enable_built_in_event_specification

        Enable built-in event specification
        """
        pass

    def test_enable_custom_event_specification(self) -> None:
        """Test case for enable_custom_event_specification

        Enable custom event specification
        """
        pass

    def test_enable_mobile_app_alert_config(self) -> None:
        """Test case for enable_mobile_app_alert_config

        Enable Mobile Smart Alert Config
        """
        pass

    def test_enable_website_alert_config(self) -> None:
        """Test case for enable_website_alert_config

        Enable Website Smart Alert Config
        """
        pass

    def test_find_active_mobile_app_alert_configs(self) -> None:
        """Test case for find_active_mobile_app_alert_configs

        Get all Mobile Smart Alert Configs
        """
        pass

    def test_find_active_website_alert_configs(self) -> None:
        """Test case for find_active_website_alert_configs

        Get all Website Smart Alert Configs
        """
        pass

    def test_find_mobile_app_alert_config(self) -> None:
        """Test case for find_mobile_app_alert_config

        Get Mobile Smart Alert Config
        """
        pass

    def test_find_mobile_app_alert_config_versions(self) -> None:
        """Test case for find_mobile_app_alert_config_versions

        Get Mobile Smart Alert Config Versions
        """
        pass

    def test_find_website_alert_config(self) -> None:
        """Test case for find_website_alert_config

        Get Website Smart Alert Config
        """
        pass

    def test_find_website_alert_config_versions(self) -> None:
        """Test case for find_website_alert_config_versions

        Get Website Smart Alert Config Versions. 
        """
        pass

    def test_get_alert(self) -> None:
        """Test case for get_alert

        Get Alert Configuration
        """
        pass

    def test_get_alerting_channel(self) -> None:
        """Test case for get_alerting_channel

        Get Alerting Channel
        """
        pass

    def test_get_alerting_channels(self) -> None:
        """Test case for get_alerting_channels

        Get all Alerting Channels
        """
        pass

    def test_get_alerting_channels_overview(self) -> None:
        """Test case for get_alerting_channels_overview

        Get Overview of Alerting Channels
        """
        pass

    def test_get_alerting_configuration_infos(self) -> None:
        """Test case for get_alerting_configuration_infos

        All alerting configuration info
        """
        pass

    def test_get_alerts(self) -> None:
        """Test case for get_alerts

        Get all Alert Configurations
        """
        pass

    def test_get_built_in_event_specification(self) -> None:
        """Test case for get_built_in_event_specification

        Built-in event specifications
        """
        pass

    def test_get_built_in_event_specifications(self) -> None:
        """Test case for get_built_in_event_specifications

        All built-in event specification
        """
        pass

    def test_get_custom_event_specification(self) -> None:
        """Test case for get_custom_event_specification

        Custom event specification
        """
        pass

    def test_get_custom_event_specifications(self) -> None:
        """Test case for get_custom_event_specifications

        All custom event specifications
        """
        pass

    def test_get_custom_payload_configurations(self) -> None:
        """Test case for get_custom_payload_configurations

        Get All Global Custom Payload Configurations
        """
        pass

    def test_get_custom_payload_tag_catalog(self) -> None:
        """Test case for get_custom_payload_tag_catalog

        Get Tag Catalog for Custom Payload
        """
        pass

    def test_get_event_specification_infos(self) -> None:
        """Test case for get_event_specification_infos

        Summary of all built-in and custom event specifications
        """
        pass

    def test_get_event_specification_infos_by_ids(self) -> None:
        """Test case for get_event_specification_infos_by_ids

        All built-in and custom event specifications
        """
        pass

    def test_get_system_rules(self) -> None:
        """Test case for get_system_rules

        All system rules for custom event specifications
        """
        pass

    def test_manually_close_event(self) -> None:
        """Test case for manually_close_event

        Manually close an event.
        """
        pass

    def test_multi_close_event(self) -> None:
        """Test case for multi_close_event

        Manually closing multiple events
        """
        pass

    def test_post_alerting_channel(self) -> None:
        """Test case for post_alerting_channel

        Create Alert Channel
        """
        pass

    def test_post_custom_event_specification(self) -> None:
        """Test case for post_custom_event_specification

        Create new custom event specification
        """
        pass

    def test_put_alert(self) -> None:
        """Test case for put_alert

        Create or update Alert Configuration
        """
        pass

    def test_put_alerting_channel(self) -> None:
        """Test case for put_alerting_channel

        Update Alert Channel
        """
        pass

    def test_put_custom_event_specification(self) -> None:
        """Test case for put_custom_event_specification

        Create or update custom event specification
        """
        pass

    def test_restore_mobile_app_alert_config(self) -> None:
        """Test case for restore_mobile_app_alert_config

        Restore Mobile Smart Alert Config
        """
        pass

    def test_restore_website_alert_config(self) -> None:
        """Test case for restore_website_alert_config

        Restore Website Smart Alert Config
        """
        pass

    def test_send_test_alerting(self) -> None:
        """Test case for send_test_alerting

        Test Alerting Channel
        """
        pass

    def test_send_test_alerting_by_id(self) -> None:
        """Test case for send_test_alerting_by_id

        Notify manually to Alerting Channel. Requires the permission called CanConfigureIntegrations.
        """
        pass

    def test_update_mobile_app_alert_config(self) -> None:
        """Test case for update_mobile_app_alert_config

        Update Mobile Smart Alert Config
        """
        pass

    def test_update_mobile_app_historic_baseline(self) -> None:
        """Test case for update_mobile_app_historic_baseline

        Recalculate Mobile Smart Alert Config Baseline
        """
        pass

    def test_update_website_alert_config(self) -> None:
        """Test case for update_website_alert_config

        Update Website Smart Alert Config
        """
        pass

    def test_update_website_historic_baseline(self) -> None:
        """Test case for update_website_historic_baseline

        Recalculate Website Smart Alert Config Baseline
        """
        pass

    def test_upsert_custom_payload_configuration(self) -> None:
        """Test case for upsert_custom_payload_configuration

        Create/Update Global Custom Payload Configuration
        """
        pass

    def test_upsert_custom_payload_configuration_v2(self) -> None:
        """Test case for upsert_custom_payload_configuration_v2

        Create/Update Global Custom Payload Configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_location import SyntheticLocation

class TestSyntheticLocation(unittest.TestCase):
    """SyntheticLocation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticLocation:
        """Test SyntheticLocation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticLocation`
        """
        model = SyntheticLocation()
        if include_optional:
            return SyntheticLocation(
                configuration = instana_client.models.synthetic_location_configuration.SyntheticLocationConfiguration(
                    cluster_name = '', 
                    namespace = '', 
                    tenant_type = 'Multi', ),
                created_at = 56,
                custom_properties = {
                    'key' : ''
                    },
                description = '',
                display_label = '0',
                geo_point = instana_client.models.synthetic_geo_point.SyntheticGeoPoint(
                    city_name = '', 
                    country_name = '', 
                    latitude = 1.337, 
                    longitude = 1.337, ),
                id = '',
                label = '0',
                location_type = '',
                modified_at = 56,
                observed_at = 56,
                playback_capabilities = instana_client.models.synthetic_playback_capabilities.SyntheticPlaybackCapabilities(
                    browser_type = [
                        'chrome'
                        ], 
                    execution_type = [
                        'CI/CD'
                        ], 
                    synthetic_type = [
                        ''
                        ], ),
                pop_version = '0',
                status = '',
                total_tests = 56
            )
        else:
            return SyntheticLocation(
                geo_point = instana_client.models.synthetic_geo_point.SyntheticGeoPoint(
                    city_name = '', 
                    country_name = '', 
                    latitude = 1.337, 
                    longitude = 1.337, ),
                label = '0',
                location_type = '',
                playback_capabilities = instana_client.models.synthetic_playback_capabilities.SyntheticPlaybackCapabilities(
                    browser_type = [
                        'chrome'
                        ], 
                    execution_type = [
                        'CI/CD'
                        ], 
                    synthetic_type = [
                        ''
                        ], ),
        )
        """

    def testSyntheticLocation(self):
        """Test SyntheticLocation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.website_analyze_api import WebsiteAnalyzeApi


class TestWebsiteAnalyzeApi(unittest.TestCase):
    """WebsiteAnalyzeApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WebsiteAnalyzeApi()

    def tearDown(self) -> None:
        pass

    def test_get_beacon_groups(self) -> None:
        """Test case for get_beacon_groups

        Get grouped beacon metrics
        """
        pass

    def test_get_beacons(self) -> None:
        """Test case for get_beacons

        Get all beacons
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.synthetic_metrics_api import SyntheticMetricsApi


class TestSyntheticMetricsApi(unittest.TestCase):
    """SyntheticMetricsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SyntheticMetricsApi()

    def tearDown(self) -> None:
        pass

    def test_get_metrics_result(self) -> None:
        """Test case for get_metrics_result

        Get Synthetic Metrics
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.app_data_metric_configuration import AppDataMetricConfiguration
from instana_client.models.order import Order
from instana_client.models.pagination import Pagination
from instana_client.models.time_frame import TimeFrame
from typing import Optional, Set
from typing_extensions import Self

class GetEndpoints(BaseModel):
    """
    GetEndpoints
    """ # noqa: E501
    application_boundary_scope: Optional[StrictStr] = Field(default=None, description="Use when querying calls of an application:  `INBOUND`: only inbound calls   `ALL`: all the calls to that application (inbound + internal)", alias="applicationBoundaryScope")
    application_id: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=64)]] = Field(default=None, description="An Instana generated unique identifier for an Application. If specified, the list of results will be filtered for the specified Application ID. Eg: `Av62RoIKQv-A3n6DbMQh9g`. One can see the application id from Instana UI by going to an Application Perspective page. In the URL, there will be `appId=Av62RoIKQv-A3n6DbMQh9g`. Alternatively, one can use `Get applications` API endpoint to get the application id in `id` parameter. ", alias="applicationId")
    endpoint_id: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=64)]] = Field(default=None, description="An Instana generated unique identifier for an Endpoint. If specified, the list of results will be filtered for the specified Endpoint ID. Eg `NCRq5oYnan5x-PkdTPQwLLUdu5M`. One can see the endpoint id from Instana UI by going to an Endpoint page. In the URL, there will be `endpointId=NCRq5oYnan5x-PkdTPQwLLUdu5M`. Alternatively, one can use `Get endpoints` API endpoint to get the endpoint id in `id` parameter. ", alias="endpointId")
    endpoint_types: Optional[Annotated[List[StrictStr], Field(min_length=0, max_length=8)]] = Field(default=None, description="A list of endpoint types, each of which is a string. An endpoint can specified for a database, an SDK, etc.", alias="endpointTypes")
    exclude_synthetic: Optional[StrictBool] = Field(default=None, description="A variable used to specify whether synthetic endpoints should be excluded. If set to 'true', synthetic endpoints will be excluded from the result.", alias="excludeSynthetic")
    metrics: Annotated[List[AppDataMetricConfiguration], Field(min_length=1, max_length=5)] = Field(description="A list of objects each of which defines a metric and the (statistical) aggregation -- MEAN, SUM, MAX, etc -- that should be used to summarize it for the defined time frame. Eg: `[{ 'metric': 'latency', 'aggregation': 'MEAN'}]`. To know more about supported metrics and its aggregation, See `Get Metric catalog`.")
    name_filter: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=256)]] = Field(default=None, description="filter by endpoint name with `contains` semantic. Eg: Let's say there are 2 Endpoint names `GET /api/fetch` and `GET /api/update`, you can set `GET /api/` here to include the two Endpoints.", alias="nameFilter")
    order: Optional[Order] = None
    pagination: Optional[Pagination] = None
    service_id: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=64)]] = Field(default=None, description="An Instana generated unique identifier for a Service. If specified, the list of results will be filtered for the specified Service ID. Eg: `3feb3dcd206c166ef2b41c707e0cd38d7cd325aa`. One can see the service id from Instana UI by going to a Service page. In the URL, there will be `serviceId=3feb3dcd206c166ef2b41c707e0cd38d7cd325aa`. Alternatively, one can use `Get services` API endpoint to get the service id in `id` parameter. ", alias="serviceId")
    time_frame: Optional[TimeFrame] = Field(default=None, alias="timeFrame")
    __properties: ClassVar[List[str]] = ["applicationBoundaryScope", "applicationId", "endpointId", "endpointTypes", "excludeSynthetic", "metrics", "nameFilter", "order", "pagination", "serviceId", "timeFrame"]

    @field_validator('application_boundary_scope')
    def application_boundary_scope_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['ALL', 'INBOUND']):
            raise ValueError("must be one of enum values ('ALL', 'INBOUND')")
        return value

    @field_validator('endpoint_types')
    def endpoint_types_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['UNDEFINED', 'RPC', 'EVENT', 'GRAPHQL', 'BATCH', 'SHELL', 'HTTP', 'SDK', 'OPENTELEMETRY', 'INTERNAL', 'DATABASE', 'MESSAGING', 'PAGE', 'PAGE_RESOURCE']):
                raise ValueError("each list item must be one of ('UNDEFINED', 'RPC', 'EVENT', 'GRAPHQL', 'BATCH', 'SHELL', 'HTTP', 'SDK', 'OPENTELEMETRY', 'INTERNAL', 'DATABASE', 'MESSAGING', 'PAGE', 'PAGE_RESOURCE')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GetEndpoints from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in metrics (list)
        _items = []
        if self.metrics:
            for _item_metrics in self.metrics:
                if _item_metrics:
                    _items.append(_item_metrics.to_dict())
            _dict['metrics'] = _items
        # override the default output from pydantic by calling `to_dict()` of order
        if self.order:
            _dict['order'] = self.order.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pagination
        if self.pagination:
            _dict['pagination'] = self.pagination.to_dict()
        # override the default output from pydantic by calling `to_dict()` of time_frame
        if self.time_frame:
            _dict['timeFrame'] = self.time_frame.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GetEndpoints from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "applicationBoundaryScope": obj.get("applicationBoundaryScope"),
            "applicationId": obj.get("applicationId"),
            "endpointId": obj.get("endpointId"),
            "endpointTypes": obj.get("endpointTypes"),
            "excludeSynthetic": obj.get("excludeSynthetic"),
            "metrics": [AppDataMetricConfiguration.from_dict(_item) for _item in obj["metrics"]] if obj.get("metrics") is not None else None,
            "nameFilter": obj.get("nameFilter"),
            "order": Order.from_dict(obj["order"]) if obj.get("order") is not None else None,
            "pagination": Pagination.from_dict(obj["pagination"]) if obj.get("pagination") is not None else None,
            "serviceId": obj.get("serviceId"),
            "timeFrame": TimeFrame.from_dict(obj["timeFrame"]) if obj.get("timeFrame") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.log_volume_group import LogVolumeGroup

class TestLogVolumeGroup(unittest.TestCase):
    """LogVolumeGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LogVolumeGroup:
        """Test LogVolumeGroup
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LogVolumeGroup`
        """
        model = LogVolumeGroup()
        if include_optional:
            return LogVolumeGroup(
                label = '',
                log_volume = 56
            )
        else:
            return LogVolumeGroup(
                label = '',
                log_volume = 56,
        )
        """

    def testLogVolumeGroup(self):
        """Test LogVolumeGroup"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.span_excerpt import SpanExcerpt

class TestSpanExcerpt(unittest.TestCase):
    """SpanExcerpt unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpanExcerpt:
        """Test SpanExcerpt
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpanExcerpt`
        """
        model = SpanExcerpt()
        if include_optional:
            return SpanExcerpt(
                data = {
                    'key' : None
                    },
                database_integrations = [
                    instana_client.models.database_integration.DatabaseIntegration(
                        type = '', 
                        url = '', )
                    ],
                duration = 0,
                error_count = 0,
                foreign_parent_id = '',
                id = '',
                kind = 'UNKNOWN',
                name = '',
                parent_id = '',
                stack_trace = [
                    instana_client.models.stack_trace_item.StackTraceItem(
                        file = '', 
                        line = '', 
                        method = '', )
                    ],
                start = 1
            )
        else:
            return SpanExcerpt(
                data = {
                    'key' : None
                    },
                id = '',
                kind = 'UNKNOWN',
                name = '',
                stack_trace = [
                    instana_client.models.stack_trace_item.StackTraceItem(
                        file = '', 
                        line = '', 
                        method = '', )
                    ],
        )
        """

    def testSpanExcerpt(self):
        """Test SpanExcerpt"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.custom_dashboard_with_user_specific_information import CustomDashboardWithUserSpecificInformation

class TestCustomDashboardWithUserSpecificInformation(unittest.TestCase):
    """CustomDashboardWithUserSpecificInformation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomDashboardWithUserSpecificInformation:
        """Test CustomDashboardWithUserSpecificInformation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomDashboardWithUserSpecificInformation`
        """
        model = CustomDashboardWithUserSpecificInformation()
        if include_optional:
            return CustomDashboardWithUserSpecificInformation(
                access_rules = [
                    instana_client.models.access_rule.AccessRule(
                        access_type = 'READ', 
                        related_id = '', 
                        relation_type = 'USER', )
                    ],
                id = '',
                owner_id = '',
                title = '',
                widgets = [
                    instana_client.models.widget.Widget(
                        config = instana_client.models.config.config(), 
                        height = 1, 
                        id = '', 
                        title = '', 
                        type = '', 
                        width = 1, 
                        x = 0, 
                        y = 0, )
                    ],
                writable = True
            )
        else:
            return CustomDashboardWithUserSpecificInformation(
                access_rules = [
                    instana_client.models.access_rule.AccessRule(
                        access_type = 'READ', 
                        related_id = '', 
                        relation_type = 'USER', )
                    ],
                id = '',
                owner_id = '',
                title = '',
                widgets = [
                    instana_client.models.widget.Widget(
                        config = instana_client.models.config.config(), 
                        height = 1, 
                        id = '', 
                        title = '', 
                        type = '', 
                        width = 1, 
                        x = 0, 
                        y = 0, )
                    ],
                writable = True,
        )
        """

    def testCustomDashboardWithUserSpecificInformation(self):
        """Test CustomDashboardWithUserSpecificInformation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.threshold_rule import ThresholdRule

class TestThresholdRule(unittest.TestCase):
    """ThresholdRule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ThresholdRule:
        """Test ThresholdRule
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ThresholdRule`
        """
        model = ThresholdRule()
        if include_optional:
            return ThresholdRule(
                aggregation = 'sum',
                condition_operator = '>',
                condition_value = 1.337,
                metric_name = '',
                metric_pattern = instana_client.models.metric_pattern.MetricPattern(
                    operator = 'is', 
                    placeholder = '', 
                    postfix = '', 
                    prefix = '', ),
                rollup = 56,
                window = 56
            )
        else:
            return ThresholdRule(
                condition_operator = '>',
        )
        """

    def testThresholdRule(self):
        """Test ThresholdRule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.geo_mapping_rule import GeoMappingRule

class TestGeoMappingRule(unittest.TestCase):
    """GeoMappingRule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GeoMappingRule:
        """Test GeoMappingRule
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GeoMappingRule`
        """
        model = GeoMappingRule()
        if include_optional:
            return GeoMappingRule(
                accuracy_radius = -1,
                cidr = '',
                city = '',
                continent = '',
                continent_code = '',
                country = '',
                country_code = '',
                latitude = 1.337,
                least_specific_subdivision = instana_client.models.geo_subdivision.GeoSubdivision(
                    code = '', 
                    name = '', ),
                longitude = 1.337,
                subdivisions = [
                    instana_client.models.geo_subdivision.GeoSubdivision(
                        code = '', 
                        name = '', )
                    ]
            )
        else:
            return GeoMappingRule(
                cidr = '',
                subdivisions = [
                    instana_client.models.geo_subdivision.GeoSubdivision(
                        code = '', 
                        name = '', )
                    ],
        )
        """

    def testGeoMappingRule(self):
        """Test GeoMappingRule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
